@@ -1063,14 +1063,20 @@ impl HttpClient {
 
         easy.signal(false)?;
 
-        request
+        let request_config = request
             .extensions()
             .get::<RequestConfig>()
-            .unwrap()
-            .set_opt(&mut easy)?;
+            .unwrap();
 
+        request_config.set_opt(&mut easy)?;
         self.inner.client_config.set_opt(&mut easy)?;
 
+        // Check if we need to disable the Expect header.
+        let disable_expect_header = request_config.expect_continue
+            .as_ref()
+            .map(|x| x.is_disabled())
+            .unwrap_or_default();
+
         // Set the HTTP method to use. Curl ties in behavior with the request
         // method, so we need to configure this carefully.
         #[allow(indirect_structural_match)]
@@ -1144,6 +1150,10 @@ impl HttpClient {
             headers.append(&header_to_curl_string(name, value, title_case))?;
         }
 
+        if disable_expect_header {
+            headers.append("Expect:")?;
+        }
+
         easy.http_headers(headers)?;
 
         Ok((easy, future))
@@ -1156,6 +1166,8 @@ impl crate::interceptor::Invoke for &HttpClient {
         mut request: Request<AsyncBody>,
     ) -> crate::interceptor::InterceptorFuture<'_, Error> {
         Box::pin(async move {
+            let is_head_request = request.method() == http::Method::HEAD;
+
             // Set default user agent if not specified.
             request
                 .headers_mut()
@@ -1202,17 +1214,21 @@ impl crate::interceptor::Invoke for &HttpClient {
 
             // Convert the reader into an opaque Body.
             Ok(response.map(|reader| {
-                let body = ResponseBody {
-                    inner: reader,
-                    // Extend the lifetime of the agent by including a reference
-                    // to its handle in the response body.
-                    _client: (*self).clone(),
-                };
-
-                if let Some(len) = body_len {
-                    AsyncBody::from_reader_sized(body, len)
+                if is_head_request {
+                    AsyncBody::empty()
                 } else {
-                    AsyncBody::from_reader(body)
+                    let body = ResponseBody {
+                        inner: reader,
+                        // Extend the lifetime of the agent by including a reference
+                        // to its handle in the response body.
+                        _client: (*self).clone(),
+                    };
+
+                    if let Some(len) = body_len {
+                        AsyncBody::from_reader_sized(body, len)
+                    } else {
+                        AsyncBody::from_reader(body)
+                    }
                 }
             }))
         })
